WebAppViewPromotion class

Widget que exibe um WebApp dentro do aplicativo Flutter. Parâmetros:

  • customerId: ID do cliente que será usado na URL da campanha.
  • campaignHash: Hash da campanha que será acessada.
  • customerAccessToken: Token de acesso para autenticação no WebApp.
  • onClose: Callback chamado quando o usuário sai da promoção ou ocorre erro de validação.
  • showDebugButton: Indica se o botão de debug deve ser exibido (default: false).
  • pageLoadedNotifier: ValueNotifier opcional que notifica quando a página terminou de carregar.
Inheritance

Constructors

WebAppViewPromotion({Key? key, required String customerId, required String campaignHash, required String customerAccessToken, required VoidCallback onClose, bool showDebugButton = false, ValuesNotifier? pageLoadedNotifier, ErrorNotifier? pageErrorNotifier})
const

Properties

campaignHash String
final
customerAccessToken String
final
customerId String
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onClose VoidCallback
final
pageErrorNotifier ErrorNotifier?
final
pageLoadedNotifier ValuesNotifier?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showDebugButton bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<WebAppViewPromotion>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited