WebResourceErrorType enum

Inheritance
Available extensions

Values

authentication → const WebResourceErrorType
badUrl → const WebResourceErrorType
connect → const WebResourceErrorType
failedSslHandshake → const WebResourceErrorType
file → const WebResourceErrorType
fileNotFound → const WebResourceErrorType
hostLookup → const WebResourceErrorType
io → const WebResourceErrorType
proxyAuthentication → const WebResourceErrorType
redirectLoop → const WebResourceErrorType
timeout → const WebResourceErrorType
tooManyRequests → const WebResourceErrorType
unknown → const WebResourceErrorType
unsafeResource → const WebResourceErrorType
unsupportedAuthScheme → const WebResourceErrorType
unsupportedScheme → const WebResourceErrorType
webContentProcessTerminated → const WebResourceErrorType
webViewInvalidated → const WebResourceErrorType
javaScriptExceptionOccurred → const WebResourceErrorType
javaScriptResultTypeIsUnsupported → const WebResourceErrorType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<WebResourceErrorType>
A constant List of the values in this enum, in order of their declaration.